@@ -20,22 +20,21 @@ sub hash_simple {
         }
     }
 
-    return unless($address =~ /^$RE{'URI'}/);
+    return unless($address =~ /^(ftp|https?):\/\//);
 
     my $ad = $data->{'EventData'}->{'Flow'}->{'System'}->{'AdditionalData'};
-    if($ad){
-        my @array;
-        if(ref($ad) eq 'ARRAY'){
-            @array = @$ad;
-        } else {
-            push(@array,$ad);
-        }
-        my ($md5,$sha1);
-        foreach my $a (@array){
-            for(lc($a->{'meaning'})){
-                $md5    = $a->{'content'} if(/^md5/);
-                $sha1   = $a->{'content'} if(/^sha1/);
-            }
+    return unless($ad);
+    my @array;
+    if(ref($ad) eq 'ARRAY'){
+        @array = @$ad;
+    } else {
+        push(@array,$ad);
+    }
+    my ($md5,$sha1);
+    foreach my $a (@array){
+        for(lc($a->{'meaning'})){
+            $md5    = $a->{'content'} if(/^md5/);
+            $sha1   = $a->{'content'} if(/^sha1/);
         }
     }
 
