@@ -54,7 +54,11 @@ sub write_out {
             $dstport = $portlist;
         }
         elsif (isdomain($_->{'address'})) {
-            $_->{'protocol'} = 17 unless($_->{'protocol'});
+            #$_->{'protocol'} = 17 unless($_->{'protocol'});
+            # override this for now, regardless of what's in $PROTOCOL
+            # most of these will be looking at udp packets
+            # if anything it should be set to undef
+            $_->{'protocol'} = 17;
             $dstport = 53;
             $dstnet = 'any';
             $dnsdomain = $_->{'address'};
@@ -111,8 +115,8 @@ sub write_out {
         } 
         elsif ($dnsdomain) {
             $rules .= "# $dnsdomain    [domain-only (dns) rule]\n";
-            # alert udp !$DNS_SERVERS any -> any 53 ( msg:"RESTRICTED - botnet domain unknown"; sid:1; content:"foo.com"; )
-            $r->opts('content', escape_content($dnsdomain));
+            # alert udp !$DNS_SERVERS any -> any 53 ( msg:"RESTRICTED - botnet domain unknown"; sid:1; content:"|03|foo|03|com"; )
+            $r->opts('content', content_as_dns_query($dnsdomain)); # dont have to escape bc we passed isdomain() test above
             $r->opts('nocase');
         } 
         else {
@@ -124,6 +128,12 @@ sub write_out {
     return $rules;
 }
 
+sub content_as_dns_query {
+    my $d = shift;
+    return '' unless $d;
+    return join('', map { sprintf("|%2.2x|%s", length($_), $_) } split('\.', $d));
+}
+
 sub isipv4 {
     my ($i, $m) = (shift, 32);
     ($i, $m) = split('/', $i) if ($i =~ /\//);
